@@ -1,7 +1,7 @@
 package Perinci::Examples;
 
-our $DATE = '2016-10-29'; # DATE
-our $VERSION = '0.76'; # VERSION
+our $DATE = '2016-12-10'; # DATE
+our $VERSION = '0.77'; # VERSION
 
 use 5.010001;
 use strict;
@@ -519,6 +519,27 @@ See also `s3`.
 
 _
         },
+        h1 => {
+            summary => 'Hash with "keys" and "allowed_keys" schema clauses and "element_completion" property',
+            schema  => ['hash', of=>'str', keys=>{k1=>"str", k2=>"str"}, allowed_keys=>[qw/k1 k2 k3 k4/]],
+            element_completion => sub {
+                my %args = @_;
+                my $word = $args{word} // "";
+                my $idx  = $args{index} // 0;
+                [ map {$word . $_ . $idx} "a".."e" ],
+            },
+        },
+        h2 => {
+            summary => 'Hash with "element_completion" as well as "index_completion" properties',
+            schema  => ['hash', of=>'str'],
+            index_completion => [qw/k1 k2 k3 k4 k5 k6/],
+            element_completion => sub {
+                my %args = @_;
+                my $word = $args{word} // "";
+                my $idx  = $args{index} // 0;
+                [ map {$word . $_ . $idx} "a".."e" ],
+            },
+        },
     },
 };
 sub test_completion {
@@ -1074,7 +1095,7 @@ Perinci::Examples - Various examples of Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.76 of Perinci::Examples (from Perl distribution Perinci-Examples), released on 2016-10-29.
+This document describes version 0.77 of Perinci::Examples (from Perl distribution Perinci-Examples), released on 2016-12-10.
 
 =head1 DESCRIPTION
 
@@ -1990,6 +2011,14 @@ A completion library can attempt to provide some possible and incremental
 completion (e.g. if word is currently at one decimal digit like 1.2, it can
 provide completion of 1.20 .. 1.29).
 
+=item * B<h1> => I<hash>
+
+Hash with "keys" and "allowed_keys" schema clauses and "element_completion" property.
+
+=item * B<h2> => I<hash>
+
+Hash with "element_completion" as well as "index_completion" properties.
+
 =item * B<i0> => I<int>
 
 Integer with just "int" schema defined.
