@@ -1,7 +1,7 @@
 package Perinci::Examples::ArgsAs;
 
-our $DATE = '2016-10-29'; # DATE
-our $VERSION = '0.76'; # VERSION
+our $DATE = '2016-12-10'; # DATE
+our $VERSION = '0.77'; # VERSION
 
 use 5.010001;
 use strict;
@@ -100,7 +100,7 @@ Perinci::Examples::ArgsAs - Demonstrate various values of `args_as` function met
 
 =head1 VERSION
 
-This document describes version 0.76 of Perinci::Examples::ArgsAs (from Perl distribution Perinci-Examples), released on 2016-10-29.
+This document describes version 0.77 of Perinci::Examples::ArgsAs (from Perl distribution Perinci-Examples), released on 2016-12-10.
 
 =head1 DESCRIPTION
 
@@ -218,7 +218,7 @@ Examples:
 
 =item * Without the optional arg3:
 
- args_as_hash(arg1 => "abc", arg2 => 10); # -> [200, "OK", ["arg2", 10, "arg1", "abc"], {}]
+ args_as_hash(arg1 => "abc", arg2 => 10); # -> [200, "OK", ["arg1", "abc", "arg2", 10], {}]
 
 =item * With the optional arg3:
 
@@ -226,7 +226,7 @@ Examples:
 
 Result:
 
- [200, "OK", ["arg2", 20, "arg3", 0.5, "arg1", "def"], {}]
+ [200, "OK", ["arg1", "def", "arg3", 0.5, "arg2", 20], {}]
 
 =back
 
