@@ -1,7 +1,7 @@
 package Perinci::Examples::CLI;
 
-our $DATE = '2016-10-29'; # DATE
-our $VERSION = '0.76'; # VERSION
+our $DATE = '2016-12-10'; # DATE
+our $VERSION = '0.77'; # VERSION
 
 use 5.010001;
 use strict;
@@ -323,7 +323,7 @@ Perinci::Examples::CLI - Example for CLI help/usage generation
 
 =head1 VERSION
 
-This document describes version 0.76 of Perinci::Examples::CLI (from Perl distribution Perinci-Examples), released on 2016-10-29.
+This document describes version 0.77 of Perinci::Examples::CLI (from Perl distribution Perinci-Examples), released on 2016-12-10.
 
 =head1 DESCRIPTION
 
@@ -378,11 +378,11 @@ Result:
    {
      logs => [
                {
-                 file    => "/home/u1/perl5/perlbrew/perls/perl-5.24.0/lib/site_perl/5.24.0/Perinci/Access/Schemeless.pm",
+                 file    => "/home/s1/perl5/perlbrew/perls/perl-5.24.0/lib/site_perl/5.24.0/Perinci/Access/Schemeless.pm",
                  func    => "Perinci::Access::Schemeless::action_call",
                  line    => 494,
                  package => "Perinci::Access::Schemeless",
-                 time    => 1477701535,
+                 time    => 1481376947,
                  type    => "create",
                },
              ],
